# Absurd Sorting Algorithms (v1.0.0)
these are the best on the market, completely free!

# Installation
`pip install absurdsortlib`

# Usage
`import absurdsortlib`<br>
Then use any of the totally valid sorting algorithms here:

- `stalinsort`: Sends non confirming numbers to the gulag!
- `bogosort`: our favorite one, random shuffling until its sorted
- `intelligentdesignsort`: there is a 1/n! chance the list was ordered in that specific way, so it must be the work of a higher diety. We shall not meddle with it
- `miraclesort`: one day...
- `movinggoalpostsort`: changes mathematics so the list is sorted
- `internsort`: this is why you hired them, right?
- `orwellsort`: Oceania allows no individuality.
- `monkeysort`: Infinite monkey theorem, but for ordering lists
- `zerosort`: multiples every number in the list with zero. Then its sorted!
- `smallchildsort` - why are you getting a small child to do it for you??
- `whenifeellikeitsort` - ehhh, i dont feel it right now. Give me 10 million or so seconds.

All of these take `list[int | float]` as an argument<br>
Additionally, `monkeysort` takes `printOutput: bool` (default to false) to print the list every time it changes<br>
Additionally, `smallchildsort` takes `giveCandy: bool` (default to false) to give candy to the child<br>
